<template>
  <div class="plan-Detail">
    <div class="containter-content">
      <van-form
        :readonly="status === 3"
        label-align="right"
        @submit="onSubmit"
      >
        <div class="form-content">
          <van-field name="radio" label="是否有隐患">
            <template #input>
              <van-radio-group
                v-model="params.greatDanger"
                direction="horizontal"
                @change="changeGreatDanger"
              >
                <van-radio name="1">是</van-radio>
                <van-radio name="2">否</van-radio>
              </van-radio-group>
            </template>
          </van-field>
          <van-field
            :disabled="boolenShow()"
            readonly
            clickable
            name="picker"
            :value="dangerTypeName"
            label="隐患类型"
            placeholder="请选择隐患类型"
            @click="showPicker = true"
          />
          <van-popup v-model="showPicker" position="bottom">
            <van-picker
              show-toolbar
              value-key="name"
              :columns="aqyhlxList"
              @confirm="dangerfirm"
              @cancel="showPicker = false"
            />
          </van-popup>
          <van-field
            :disabled="boolenShow()"
            v-model="params.reformUnitname"
            label="整改负责机构"
            placeholder="请输入整改负责机构"
          />
          <van-field
            :disabled="boolenShow()"
            readonly
            clickable
            name="datetimePicker"
            :value="params.checkDate"
            label="检查时间"
            placeholder="请选择检查时间"
            @click="showPickerTime = true"
            :rules="[{required: true, message: '请选择检查时间'}]"
            @change="latestTimeInput"
          />
          <van-popup v-model="showPickerTime" position="bottom">
            <van-datetime-picker
              type="date"
              @confirm="onConfirmTime"
              @cancel="showPickerTime = false"
            />
          </van-popup>
          <van-field
            :disabled="boolenShow()"
            @input="latestTimeInput"
            v-model="params.latestTimeLimit"
            name="最迟整改期限"
            label="最迟整改期限"
            placeholder="请输入最迟整改期限(天)"
            :rules="[{required: true, message: '请输入最迟整改期限'}]"
          />
          <van-field
            disabled
            v-model="params.latestReviewDate"
            name="最迟复查时间"
            label="最迟复查时间"
            placeholder="请输入最迟复查时间"
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.leadUsername"
            name="带队领导"
            label="带队领导"
            placeholder="请输入带队领导"
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.reformUsername"
            name="整改负责人"
            label="整改负责人"
            placeholder="请输入整改负责人"
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.checkUsername"
            rows="2"
            autosize
            label="检查组成员"
            type="textarea"
            maxlength="50"
            placeholder="请输入检查组成员"
            show-word-limit
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.checkContent"
            rows="2"
            autosize
            label="检查情况描述"
            type="textarea"
            maxlength="50"
            placeholder="请输入检查情况描述"
            show-word-limit
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.reformRequire"
            rows="2"
            autosize
            label="整改措施总体要求描述"
            type="textarea"
            maxlength="50"
            placeholder="请输入整改措施总体要求描述"
            show-word-limit
          />
          <van-field
            :disabled="boolenShow()"
            v-model="params.controlMemo"
            rows="2"
            autosize
            label="临时管制措施描述"
            type="textarea"
            maxlength="50"
            placeholder="请输入临时管制措施描述"
            show-word-limit
          />
        </div>
        <div class="form-button" style="margin: 10px 16px;">
          <van-button
            v-if="status !== '3'"
            style="color:#3F86FF"
            @click="handleSave"
            size="large"
            type="default"
            native-type="submit"
          >保存
          </van-button
          >
          <van-button
            style="margin-top:10px"
            @click="previousStep"
            size="large"
            type="info"
          >上一步
          </van-button
          >
        </div>
      </van-form>
    </div>
  </div>
</template>

<script>
import moment from 'moment'
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import programApi from '@/views/Manage/saftyDanger/api/programApi'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'MobileSaftyTreatCheckPlanDetail',
  data() {
    return {
      status: '',
      showPickerTime: false,
      dangerTypeName: '',
      aqyhlxList: [],
      schemeList: [],
      value: '',
      showCalendar: false,
      showPicker: false,
      title: '新增',
      deviceData: {},
      situation: '',
      loading: false,
      params: {
        checkschemeId: null,
        checkYearMonth: null,
        unitType: null,
        unitName: null,
        unitId: null,
        unitAddress: null,
        recordName: null,
        unitUserphone: null,
        dangerType: null,
        greatDanger: null,
        checkDate: null,
        checkContent: null,
        leadUsername: null,
        checkUsername: null,
        // status: null,
        reformUsername: null,
        reformUnitname: null,
        latestTimeLimit: null,
        latestReviewDate: null,
        completeDate: null,
        reformRequire: null,
        unitUsername: null,
        controlMemo: null,
        // reformContent: null,
        detail: []
      }
    }
  },
  created() {
    this.aqyhlxList = dictUtils.getDictItemsFromCache('cmgt_aqyhlx')
    this.getScheme()
  },
  mounted() {
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    this.deviceAzlc = dictUtils.getDictItemsFromCache('azlc')
    this.deviceAzddlx = dictUtils.getDictItemsFromCache('azddlx')
    this.device = this.$route.query.id
    this.status = this.$route.query.status
    this.Update(this.device)
  },
  methods: {
    //上一步
    previousStep() {
      this.$router.go(-1)
    },
    // 是否禁用及必填
    boolenShow() {
      if (!this.params.greatDanger || this.params.greatDanger === '2') {
        return true
      } else {
        return false
      }
    },
    //保存
    handleSave() {
      let method
      if (!this.params.id) {
        // 新增
        method = CmgtSaftyDangerCheckrecordApi.addCmgtSaftyDangerCheckrecord
      }
      if (this.params.id) {
        // 修改
        method = CmgtSaftyDangerCheckrecordApi.editCmgtSaftyDangerCheckrecord
      }
      this.params.detail.forEach(item => {
        if (item.reformImgUrlArray) {
          item.reformStatus = 2
        }
      })
      method(this.params, res => {
        if (res.state) {
          this.$toast.success({
            message: this.title + '成功'
          })
          this.$router.push({name: 'MobileSaftyDangerCheckPlan'})
          this.handleClose()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    handleClose() {
      this.params = {
        checkschemeId: null,
        checkYearMonth: null,
        unitType: null,
        unitName: null,
        unitId: null,
        unitAddress: null,
        unitUserphone: null,
        dangerType: null,
        greatDanger: null,
        checkDate: null,
        checkContent: null,
        leadUsername: null,
        unitUsername: null,
        checkUsername: null,
        recordName: null,
        // status: null,
        reformUsername: null,
        reformUnitname: null,
        latestTimeLimit: null,
        latestReviewDate: null,
        completeDate: null,
        reformRequire: null,
        controlMemo: null,
        // reformContent: null,
        detail: []
      }
      this.title = '新增'
      // this.$emit('refreshList')
    },
    //最迟整改期限
    latestTimeInput() {
      if (this.params.latestTimeLimit && this.params.checkDate) {
        this.params.latestReviewDate = this.dayjs(this.params.checkDate)
          .add(this.params.latestTimeLimit, 'day')
          .format('YYYY-MM-DD')
      } else {
        this.params.latestReviewDate = null
      }
    },
    //请选择检查时间
    onConfirmTime(item) {
      this.params.checkDate = moment(item).format('YYYY-MM-DD')
      this.showPickerTime = false
    },
    //隐患类型
    dangerfirm(val) {
      this.dangerTypeName = val.name
      this.params.dangerType = val.value
      this.showPicker = false
    },
    // 切换是否存在重大隐患
    changeGreatDanger(val) {
      if (val === '2') {
        this.params.dangerType = null
        this.params.reformUnitname = null
        this.params.checkDate = null
        this.params.latestTimeLimit = null
        this.params.latestReviewDate = null
        this.params.leadUsername = null
        this.params.reformUsername = null
        this.params.checkUsername = null
        this.params.checkContent = null
        this.params.reformRequire = null
        this.params.controlMemo = null
        // this.rules.checkDate[0].required = false
        // this.rules.latestTimeLimit[0].required = false
      } else {
        // this.rules.checkDate[0].required = true
        // this.rules.latestTimeLimit[0].required = true
      }
    },
    //
    DangerUnitId(id) {
      CmgtSaftyDangerCheckrecordApi.cmgtSaftyDangerUnitId(id, res => {
        this.params.unitAddress = res.unitAddress
        this.params.unitUsername = res.name
        this.params.unitUserphone = res.phone
        this.params.unitType = res.type
      })
    },
    //选择检查方案后自动填充字段检查年度
    CheckschemeId(id) {
      CmgtSaftyDangerCheckrecordApi.cmgtSaftyDangerCheckschemeId(id, res => {
        this.params.checkYearMonth = res.checkYearMonth
      })
    },
    //排查方案列表
    getScheme() {
      programApi.loadCmgtSaftyDangerUnit(
        {
          pageBean: {
            pageSize: -1,
            page: 1
          }
        },
        res => {
          this.schemeList = res.rows.map(item => {
            return {
              text: item.schemeName,
              value: item.id
            }
          })
        }
      )
    },
    onSubmit(values) {
    },
    onClickLeft() {
      this.$router.push({name: 'MobileSaftyDangerCheckPlan'})
    },
    Update(id) {
      this.readType = false
      this.title = '修改'
      // this.fromType = type
      this.showFormDia = true
      CmgtSaftyDangerCheckrecordApi.getItemById(id, res => {
        this.params.id = res.id
        this.params.checkschemeId = res.checkschemeId
        this.params.checkYearMonth = res.checkYearMonth
        this.params.unitType = res.unitType
        this.params.unitName = res.unitName
        this.params.unitId = res.unitId
        this.params.unitAddress = res.unitAddress
        this.params.unitUserphone = res.unitUserphone
        this.params.dangerType = res.dangerType
        this.params.unitUsername = res.unitUsername
        this.params.greatDanger = res.greatDanger
        this.params.checkDate = res.checkDate
        this.params.checkContent = res.checkContent
        this.params.leadUsername = res.leadUsername
        this.params.checkUsername = res.checkUsername
        this.params.recordName = res.recordName
        this.params.status = res.status
        this.params.reformUsername = res.reformUsername
        this.params.reformUnitname = res.reformUnitname
        this.params.latestTimeLimit = res.latestTimeLimit
        this.params.latestReviewDate = res.latestReviewDate
        this.params.completeDate = res.completeDate
        this.params.reformRequire = res.reformRequire
        this.params.controlMemo = res.controlMemo
        // this.params.reformContent = res.reformContent
        this.params.detail = res.detail
        this.CheckschemeId(res.checkschemeId)
        this.DangerUnitId(res.unitId)
      })
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.plan-Detail {
  width: 100%;
  box-sizing: border-box;
  // background-color: $--mobile-bg;
  background-color: #f9f9f9;
  overflow-y: scroll;
  padding: 100px 60px 0px 60px;

  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }
}

::v-deep .van-cell::after {
  border-bottom: 0;
}

.hidden-trouble {
  background-color: white;

  .trouble-Btn {
    display: flex;
    justify-content: flex-end;
    padding: 20px 20px 0 0;
  }

  .trouble-content {
    display: flex;
    justify-content: space-between;
    align-items: center;
  }

  .trouble-title {
    // font-weight: bold;
    font-size: 80px;
    margin: 0;
    margin-left: 80px;
  }
}

.device-content {
  // padding: 50px 0px 50px 0px;
  height: 400px;
  font-size: 50px;

  p {
    color: #929494;
    margin: 10px 0 10px 0;
  }
}

.device-group {
  padding: 0 60px 0 60px;
  margin-top: 16px !important;
}

.group-title {
  padding: 20px 16px 10px 16px;
  color: #888888;
  font-size: 78px;
}

.title-bar {
  display: inline-block;
  width: 4px;
  height: 12px;
  background-color: #1989fa;
  margin-right: 4px;
  vertical-align: middle;
}

.device-cell {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 40px 0 40px 0;
  border-bottom: 1px solid #dedddd;
}

.device-name {
  font-size: 88px;
  color: $--mobile-text-main;
}

.cell-title {
  color: $--mobile-text-sub;
  font-size: 82px;
  margin-right: 10px;
}

.cell-value {
  color: $--mobile-text-main;
  font-size: 82px;
}

.margin-bottom {
  margin-bottom: 16px !important;
}

.device-status .van-tag {
  padding: 10px 40px 10px 40px;
  font-size: 72px;
}

.van-cell-group--inset {
  margin: 0 0;
  border-radius: 0;
}

.van-cell {
  justify-content: start;
}

.van-cell__title,
.van-cell__value {
  width: auto;
  flex: initial;
}

.van-cell__title {
  white-space: nowrap;
}

.van-cell__value {
  padding-left: 10px;
  text-align: left;
}

.van-cell__title span,
.van-cell__value span {
  font-size: 76px;
  color: $--mobile-text-main;
}

.van-cell__title span {
  color: $--mobile-text-sub;
}

.form-content {
  box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.15), 0 6px 20px 0 rgba(0, 0, 0, 0.1);
  border-radius: 50px;
  overflow: hidden;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom';
</style>
